Crate mrdirector

mrdirector

mrdirector is an extension package for the turbo game engine to help streamline the creation of games with branching narratives warning: this project is in hyper omega alpha, so use at your own risk

Structs

DirectorState
A state object to hold information required by the mrdirector package.
TextOverlay
An object to hold data associated with the TextOverlay that displays the assessed lines from the script.director file.

Enums

TextOverlayLocation
Options as to where to put the textbox used to display the current line.

Functions

assess_current_line
A function to retrieve and display the current line out of the script.director file.