mrdirector
mrdirector is an extension package for the turbo game engine
to help streamline the creation of games with branching narratives
warning: this project is in hyper omega alpha, so use at your own risk
Structs
- Director
State - A state object to hold information required by the
mrdirectorpackage. - Text
Overlay - An object to hold data associated with the TextOverlay that displays the assessed lines from the
script.directorfile.
Enums
- Text
Overlay Location - Options as to where to put the textbox used to display the current line.
Functions
- assess_
current_ line - A function to retrieve and display the current line out of the
script.directorfile.